@@ -114,7 +114,7 @@ func RequestObjectClaims(params url.Values, serverConfig ServerConfig, clientCon
 
 			val := values[0]
 
-			if len(val) > 0 && val[0] == '{' {
+			if len(val) > 0 && (val[0] == '{' || val[0] == '[') {
 				claims[key] = json.RawMessage(val)
 			} else {
 				claims[key] = val
