@@ -215,26 +215,24 @@ func (r *Request) ParseJARM(signingKey interface{}, encryptionKey interface{}) e
 
 	r.JARM = map[string]interface{}{}
 
-	if response != "" {
-		if nestedToken, err = jwt.ParseSignedAndEncrypted(response); err != nil {
-			if token, err2 = jwt.ParseSigned(response); err2 != nil {
-				return errors.Wrapf(multierror.Append(err, err2), "failed to parse JARM response")
-			}
-		} else if encryptionKey != nil {
-			if token, err = nestedToken.Decrypt(encryptionKey); err != nil {
-				return errors.Wrapf(err, "failed to decrypt encrypted JARM response")
-			}
-		} else {
-			return errors.New("no encryption key path")
+	if nestedToken, err = jwt.ParseSignedAndEncrypted(response); err != nil {
+		if token, err2 = jwt.ParseSigned(response); err2 != nil {
+			return errors.Wrapf(multierror.Append(err, err2), "failed to parse JARM response")
 		}
+	} else if encryptionKey != nil {
+		if token, err = nestedToken.Decrypt(encryptionKey); err != nil {
+			return errors.Wrapf(err, "failed to decrypt encrypted JARM response")
+		}
+	} else {
+		return errors.New("no encryption key path")
+	}
 
-		if signingKey == nil {
-			return errors.New("no signing key path")
-		}
+	if signingKey == nil {
+		return errors.New("no signing key path")
+	}
 
-		if err = token.Claims(signingKey, &r.JARM); err != nil {
-			return err
-		}
+	if err = token.Claims(signingKey, &r.JARM); err != nil {
+		return err
 	}
 
 	return nil
